@@ -5,8 +5,7 @@ import os,sys
 import time
 from os.path import expanduser
 from multiprocessing import Lock
-from multiprocessing.dummy import Pool as ThreadPool 
-
+from multiprocessing.dummy import Pool as ThreadPool
 from wcs.commons.config import Config
 from wcs.commons.http import _post
 from wcs.commons.logme import debug,warning,error
@@ -15,7 +14,7 @@ from wcs.commons.util import urlsafe_base64_encode,https_check
 
 from wcs.services.uploadprogressrecorder import UploadProgressRecorder
 
-config_file = os.path.join(expanduser("~"), ".wcscfg")
+#config_file = os.path.join(expanduser("~"), ".wcscfg")
 
 lock = Lock()
 
@@ -51,7 +50,8 @@ class MultipartUpload(object):
         self.uploadBatch = ''
         self.progress = 0
         self.recorder = None
-        self.cfg = Config(config_file)
+        #self.cfg = Config(config_file)
+        self.cfg = Config()
         try:
             self.concurrency = int(self.cfg.concurrency)
             self.block_size = int(self.cfg.block_size)
